@@ -66,10 +66,10 @@ class EffectId(IntEnum):
     - location_x
     - location_y
     - location_object_reference
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - object_group
     - object_type
     - selected_object_ids"""
@@ -81,10 +81,10 @@ class EffectId(IntEnum):
     """Attributes for the **kill_object** effect are: \n
     - object_list_unit_id
     - source_player
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - object_group
     - object_type
     - selected_object_ids"""
@@ -92,10 +92,10 @@ class EffectId(IntEnum):
     """Attributes for the **remove_object** effect are: \n
     - object_list_unit_id
     - source_player
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - object_group
     - object_type
     - selected_object_ids"""
@@ -104,7 +104,6 @@ class EffectId(IntEnum):
     - source_player
     - location_x
     - location_y
-    - location_object_reference
     - scroll"""
     UNLOAD = 17
     """Attributes for the **unload** effect are: \n
@@ -113,10 +112,10 @@ class EffectId(IntEnum):
     - location_x
     - location_y
     - location_object_reference
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - object_group
     - object_type
     - selected_object_ids"""
@@ -125,10 +124,10 @@ class EffectId(IntEnum):
     - object_list_unit_id
     - source_player
     - target_player
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - object_group
     - object_type
     - flash_object
@@ -140,10 +139,10 @@ class EffectId(IntEnum):
     - location_x
     - location_y
     - location_object_reference
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - object_group
     - object_type
     - selected_object_ids"""
@@ -164,10 +163,10 @@ class EffectId(IntEnum):
     """Attributes for the **freeze_object** effect are: \n
     - object_list_unit_id
     - source_player
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - object_group
     - object_type
     - selected_object_ids"""
@@ -180,10 +179,10 @@ class EffectId(IntEnum):
     - quantity
     - object_list_unit_id
     - source_player
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - object_group
     - object_type
     - selected_object_ids"""
@@ -198,10 +197,10 @@ class EffectId(IntEnum):
     - object_list_unit_id
     - source_player
     - string_id
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - message
     - selected_object_ids"""
     CHANGE_OBJECT_HP = 27
@@ -209,10 +208,10 @@ class EffectId(IntEnum):
     - quantity
     - object_list_unit_id
     - source_player
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - object_group
     - object_type
     - operation
@@ -223,10 +222,10 @@ class EffectId(IntEnum):
     - armour_attack_class
     - object_list_unit_id
     - source_player
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - object_group
     - object_type
     - operation
@@ -235,10 +234,10 @@ class EffectId(IntEnum):
     """Attributes for the **stop_object** effect are: \n
     - object_list_unit_id
     - source_player
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - object_group
     - object_type
     - selected_object_ids"""
@@ -249,10 +248,10 @@ class EffectId(IntEnum):
     - location_x
     - location_y
     - location_object_reference
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - object_group
     - object_type
     - selected_object_ids"""
@@ -262,10 +261,10 @@ class EffectId(IntEnum):
     - armour_attack_class
     - object_list_unit_id
     - source_player
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - object_group
     - object_type
     - operation
@@ -275,10 +274,10 @@ class EffectId(IntEnum):
     - quantity
     - object_list_unit_id
     - source_player
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - object_group
     - object_type
     - operation
@@ -288,10 +287,10 @@ class EffectId(IntEnum):
     - quantity
     - object_list_unit_id
     - source_player
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - object_group
     - object_type
     - selected_object_ids"""
@@ -300,10 +299,10 @@ class EffectId(IntEnum):
     - quantity
     - object_list_unit_id
     - source_player
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - object_group
     - object_type
     - selected_object_ids"""
@@ -313,10 +312,10 @@ class EffectId(IntEnum):
     - source_player
     - location_x
     - location_y
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - object_group
     - object_type
     - selected_object_ids"""
@@ -324,10 +323,10 @@ class EffectId(IntEnum):
     """Attributes for the **change_object_stance** effect are: \n
     - object_list_unit_id
     - source_player
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - object_group
     - object_type
     - attack_stance
@@ -368,10 +367,10 @@ class EffectId(IntEnum):
     """Attributes for the **change_object_icon** effect are: \n
     - object_list_unit_id
     - source_player
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - object_group
     - object_type
     - object_list_unit_id_2
@@ -381,10 +380,10 @@ class EffectId(IntEnum):
     - object_list_unit_id
     - source_player
     - target_player
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - object_group
     - object_type
     - object_list_unit_id_2
@@ -421,10 +420,10 @@ class EffectId(IntEnum):
     """Attributes for the **create_garrisoned_object** effect are: \n
     - object_list_unit_id
     - source_player
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - object_list_unit_id_2
     - selected_object_ids"""
     ACKNOWLEDGE_AI_SIGNAL = 50
@@ -458,10 +457,10 @@ class EffectId(IntEnum):
     - source_player
     - location_x
     - location_y
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - selected_object_ids"""
     SCRIPT_CALL = 55
     """Attributes for the **script_call** effect are: \n
@@ -480,47 +479,47 @@ class EffectId(IntEnum):
     """Attributes for the **change_object_player_color** effect are: \n
     - object_list_unit_id
     - source_player
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - player_color
     - selected_object_ids"""
     CHANGE_OBJECT_CIVILIZATION_NAME = 59
     """Attributes for the **change_object_civilization_name** effect are: \n
     - string_id
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - selected_object_ids"""
     CHANGE_OBJECT_PLAYER_NAME = 60
     """Attributes for the **change_object_player_name** effect are: \n
     - object_list_unit_id
     - source_player
     - string_id
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - selected_object_ids"""
     DISABLE_UNIT_TARGETING = 61
     """Attributes for the **disable_unit_targeting** effect are: \n
     - object_list_unit_id
     - source_player
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - selected_object_ids"""
     ENABLE_UNIT_TARGETING = 62
     """Attributes for the **enable_unit_targeting** effect are: \n
     - object_list_unit_id
     - source_player
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - selected_object_ids"""
     CHANGE_TECHNOLOGY_COST = 63
     """Attributes for the **change_technology_cost** effect are: \n
@@ -563,20 +562,24 @@ class EffectId(IntEnum):
     """Attributes for the **disable_object_selection** effect are: \n
     - object_list_unit_id
     - source_player
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - selected_object_ids"""
     ENABLE_OBJECT_SELECTION = 71
     """Attributes for the **enable_object_selection** effect are: \n
     - object_list_unit_id
     - source_player
-    - area_1_x
-    - area_1_y
-    - area_2_x
-    - area_2_y
+    - area_x1
+    - area_y1
+    - area_x2
+    - area_y2
     - selected_object_ids"""
+    CHANGE_COLOR_MOOD = 72
+    """Attributes for the **change_color_mood** effect are: \n
+    - quantity
+    - color_mood"""
     # Possibly used for marking when achievements should be achieved. Doesn't seem to work in scenario's. F
     # UNKNOWN_0 = 58  # Was 58... Not anymore (?)
 
@@ -599,10 +602,10 @@ empty_attributes = {
     "location_x": -1,
     "location_y": -1,
     "location_object_reference": -1,
-    "area_1_x": -1,
-    "area_1_y": -1,
-    "area_2_x": -1,
-    "area_2_y": -1,
+    "area_x1": -1,
+    "area_y1": -1,
+    "area_x2": -1,
+    "area_y2": -1,
     "object_group": -1,
     "object_type": -1,
     "instruction_panel_position": -1,
